@@ -19,8 +19,12 @@ public class TGBackAction extends TGActionBase{
 	protected void processAction(final TGActionContext context) {
 		TGActivity tgActivity = (TGActivity) context.getAttribute(ATTRIBUTE_ACTIVITY);
 		if(!tgActivity.getNavigationManager().callOpenPreviousFragment()) {
-			TGActionManager tgActionManager = TGActionManager.getInstance(getContext());
-			tgActionManager.execute(TGFinishAction.NAME, context);
+			new Thread(new Runnable() {
+				public void run() {
+					TGActionManager tgActionManager = TGActionManager.getInstance(getContext());
+					tgActionManager.execute(TGExitAction.NAME, context);
+				}
+			}).start();
 		}
 	}
 }
