@@ -2,6 +2,7 @@ package org.herac.tuxguitar.android.action.listener.cache.controller;
 
 import org.herac.tuxguitar.action.TGActionContext;
 import org.herac.tuxguitar.editor.undo.TGUndoableManager;
+import org.herac.tuxguitar.player.base.MidiPlayer;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGUpdateLoadedSongController extends TGUpdateItemsController {
@@ -12,6 +13,11 @@ public class TGUpdateLoadedSongController extends TGUpdateItemsController {
 
 	@Override
 	public void update(TGContext context, TGActionContext actionContext) {
+		MidiPlayer midiPlayer = MidiPlayer.getInstance(context);
+		midiPlayer.reset();
+		midiPlayer.getMode().clear();
+		midiPlayer.resetChannels();
+		
 		TGUndoableManager.getInstance(context).discardAllEdits();
 
 		this.findUpdateBuffer(context).requestUpdateLoadedSong();
