@@ -1,8 +1,9 @@
 package org.herac.tuxguitar.android.application;
 
 import android.content.Context;
-import android.support.multidex.MultiDex;
-import android.support.multidex.MultiDexApplication;
+
+import androidx.multidex.MultiDex;
+import androidx.multidex.MultiDexApplication;
 
 public class TGApplication extends MultiDexApplication {
 	
