@@ -4,6 +4,7 @@ import org.herac.tuxguitar.android.browser.TGBrowserCollection;
 import org.herac.tuxguitar.android.browser.TGBrowserManager;
 import org.herac.tuxguitar.android.browser.model.TGBrowserFactorySettingsHandler;
 import org.herac.tuxguitar.android.browser.model.TGBrowserSettings;
+import org.herac.tuxguitar.util.error.TGErrorManager;
 
 public class TGBrowserCollectionsSettingsHandler implements TGBrowserFactorySettingsHandler {
 	
@@ -15,10 +16,31 @@ public class TGBrowserCollectionsSettingsHandler implements TGBrowserFactorySett
 		this.type = type;
 	}
 	
-	public void onCreateSettings(TGBrowserSettings settings) {
+	public void onCreateSettings(final TGBrowserSettings settings) {
+		this.dialog.postWhenReady(new Runnable() {
+			public void run() {
+				postOnCreateSettings(settings);
+			}
+		});
+	}
+
+	@Override
+	public void handleError(final Throwable throwable) {
+		this.dialog.postWhenReady(new Runnable() {
+			public void run() {
+				postHandleError(throwable);
+			}
+		});
+	}
+
+	public void postOnCreateSettings(TGBrowserSettings settings) {
 		TGBrowserManager browserManager = TGBrowserManager.getInstance(this.dialog.findContext());
 		TGBrowserCollection collection = browserManager.createCollection(this.type, settings);
-		
+
 		this.dialog.addCollection(collection);
 	}
+
+	public void postHandleError(Throwable throwable) {
+		TGErrorManager.getInstance(this.dialog.findContext()).handleError(throwable);
+	}
 }
