@@ -3,7 +3,7 @@ package org.herac.tuxguitar.android.view.dialog.chooser;
 import android.annotation.SuppressLint;
 import android.app.Dialog;
 import android.content.DialogInterface;
-import android.support.v7.app.AlertDialog;
+import androidx.appcompat.app.AlertDialog;
 
 import org.herac.tuxguitar.android.view.dialog.fragment.TGDialogFragment;
 
