@@ -1,7 +1,6 @@
 package org.herac.tuxguitar.android.view.dialog.fragment;
 
-import android.app.Activity;
-
+import org.herac.tuxguitar.android.activity.TGActivity;
 import org.herac.tuxguitar.android.application.TGApplicationUtil;
 import org.herac.tuxguitar.android.view.dialog.TGDialogContext;
 import org.herac.tuxguitar.android.view.dialog.TGDialogController;
@@ -11,11 +10,11 @@ public abstract class TGDialogFragmentController<T extends TGDialogFragment> imp
 
 	public abstract T createNewInstance();
 
-	public void showDialog(Activity activity, TGDialogContext context) {
+	public void showDialog(TGActivity activity, TGDialogContext context) {
 		TGDialogFragment dialog = this.createNewInstance();
 		TGContext tgContext = TGApplicationUtil.findContext(activity);
 		tgContext.setAttribute(dialog.getDialogContextKey(), context);
 
-		dialog.show(activity.getFragmentManager(), "NoticeDialogFragment");
+		dialog.show(activity.getSupportFragmentManager(), "NoticeDialogFragment");
 	}
 }
