@@ -1,7 +1,7 @@
 package org.herac.tuxguitar.android.view.dialog.tremoloBar;
 
 import android.content.Context;
-import android.support.v4.view.GestureDetectorCompat;
+import androidx.core.view.GestureDetectorCompat;
 import android.view.GestureDetector;
 import android.view.MotionEvent;
 
