@@ -1,6 +1,5 @@
 package org.herac.tuxguitar.player.impl.midiport.vst.remote;
 
-import org.herac.tuxguitar.midi.synth.TGAudioProcessorFactoryCallback;
 import org.herac.tuxguitar.midi.synth.TGMidiProcessor;
 import org.herac.tuxguitar.midi.synth.TGMidiProcessorFactory;
 import org.herac.tuxguitar.util.TGContext;
@@ -17,11 +16,12 @@ public class VSTMidiProcessorFactory implements TGMidiProcessorFactory {
 		return VSTType.VSTI.toString();
 	}
 	
-	public void createProcessor(TGAudioProcessorFactoryCallback<TGMidiProcessor> callback) {
+	public TGMidiProcessor createProcessor() {
 		try {
-			callback.onCreate(new VSTMidiProcessor(this.context));
+			return new VSTMidiProcessor(this.context);
 		} catch (Throwable e) {
 			e.printStackTrace();
 		}
+		return null;
 	}
 }
