@@ -4,6 +4,8 @@ import java.net.URL;
 
 import org.herac.tuxguitar.ui.UIApplication;
 import org.herac.tuxguitar.ui.UIFactory;
+import org.herac.tuxguitar.ui.appearance.UIAppearance;
+import org.herac.tuxguitar.ui.qt.appearance.QTAppearance;
 import org.qtjambi.qt.core.QUrl;
 import org.qtjambi.qt.gui.QDesktopServices;
 
@@ -11,6 +13,7 @@ public class QTApplication extends QTComponent<QTApplicationHandle> implements U
 	
 	private Thread uiThread;
 	private UIFactory uiFactory;
+	private UIAppearance uiAppearance;
 	private QTEnvironment environment;
 	
 	public QTApplication(String name) {
@@ -18,6 +21,7 @@ public class QTApplication extends QTComponent<QTApplicationHandle> implements U
 		
 		this.environment = new QTEnvironment();
 		this.uiFactory = new QTFactory();
+		this.uiAppearance = new QTAppearance();
 		
 		this.getControl().setApplicationName(name);
 	}
@@ -32,6 +36,10 @@ public class QTApplication extends QTComponent<QTApplicationHandle> implements U
 		return this.uiFactory;
 	}
 	
+	public UIAppearance getAppearance() {
+		return this.uiAppearance;
+	}
+	
 	public void openUrl(URL url) {
 		QDesktopServices.openUrl(new QUrl(url.toExternalForm()));
 	}
