@@ -7,7 +7,7 @@ import org.herac.tuxguitar.app.TuxGuitar;
 import org.herac.tuxguitar.app.action.TGActionProcessorListener;
 import org.herac.tuxguitar.app.action.impl.track.TGGoNextTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGGoPreviousTrackAction;
-import org.herac.tuxguitar.app.system.icons.TGIconEvent;
+import org.herac.tuxguitar.app.system.icons.TGSkinEvent;
 import org.herac.tuxguitar.app.system.keybindings.KeyBindingAction;
 import org.herac.tuxguitar.app.system.keybindings.KeyBindingActionManager;
 import org.herac.tuxguitar.app.system.language.TGLanguageEvent;
@@ -31,7 +31,7 @@ import org.herac.tuxguitar.ui.event.UIDisposeListener;
 import org.herac.tuxguitar.ui.event.UIKeyEvent;
 import org.herac.tuxguitar.ui.event.UIKeyPressedListener;
 import org.herac.tuxguitar.ui.layout.UITableLayout;
-import org.herac.tuxguitar.ui.resource.UIKeyConvination;
+import org.herac.tuxguitar.ui.resource.UIKeyCombination;
 import org.herac.tuxguitar.ui.resource.UIRectangle;
 import org.herac.tuxguitar.ui.widget.UIButton;
 import org.herac.tuxguitar.ui.widget.UILabel;
@@ -114,13 +114,13 @@ public class TGLyricEditor implements TGEventListener {
 	}
 	
 	public void addListeners(){
-		TuxGuitar.getInstance().getIconManager().addLoader(this);
+		TuxGuitar.getInstance().getSkinManager().addLoader(this);
 		TuxGuitar.getInstance().getLanguageManager().addLoader(this);
 		TuxGuitar.getInstance().getEditorManager().addUpdateListener(this);
 	}
 	
 	public void removeListeners(){
-		TuxGuitar.getInstance().getIconManager().removeLoader(this);
+		TuxGuitar.getInstance().getSkinManager().removeLoader(this);
 		TuxGuitar.getInstance().getLanguageManager().removeLoader(this);
 		TuxGuitar.getInstance().getEditorManager().removeUpdateListener(this);
 	}
@@ -188,7 +188,7 @@ public class TGLyricEditor implements TGEventListener {
 		this.text.addKeyPressedListener(new UIKeyPressedListener() {
 			public void onKeyPressed(UIKeyEvent event) {
 				for(KeyBindingAction keyBinding : TGLyricEditor.this.keyBindings) {
-					if( event.getKeyConvination().equals(keyBinding.getConvination()) ){
+					if( event.getKeyCombination().equals(keyBinding.getCombination()) ){
 						new TGActionProcessorListener(TGLyricEditor.this.context, keyBinding.getAction()).processEvent(event);
 						return;
 					}
@@ -292,9 +292,9 @@ public class TGLyricEditor implements TGEventListener {
 	}
 	
 	public void loadKeyBinding(String actionId) {
-		UIKeyConvination keyConvination = KeyBindingActionManager.getInstance(this.context).getKeyBindingForAction(actionId);
-		if( keyConvination != null ) {
-			this.keyBindings.add(new KeyBindingAction(actionId, keyConvination));
+		UIKeyCombination keyCombination = KeyBindingActionManager.getInstance(this.context).getKeyBindingForAction(actionId);
+		if( keyCombination != null ) {
+			this.keyBindings.add(new KeyBindingAction(actionId, keyCombination));
 		}
 	}
 	
@@ -376,7 +376,7 @@ public class TGLyricEditor implements TGEventListener {
 	}
 	
 	public void processEvent(final TGEvent event) {
-		if( TGIconEvent.EVENT_TYPE.equals(event.getEventType()) ) {
+		if( TGSkinEvent.EVENT_TYPE.equals(event.getEventType()) ) {
 			this.loadIconsProcess.process();
 		}
 		else if( TGLanguageEvent.EVENT_TYPE.equals(event.getEventType()) ) {
